@@ -53,7 +53,7 @@ pub enum TemplateArgument {
 impl Display for TemplateArgument {
     fn fmt(&self, out: &mut fmt::Formatter) -> Result<(), fmt::Error> {
         match *self {
-            TemplateArgument::Rust(ref s) => out.write_str(&s),
+            TemplateArgument::Rust(ref s) => out.write_str(s),
             TemplateArgument::Body(ref v) if v.is_empty() => {
                 out.write_str("|_| Ok(())")
             }
@@ -82,7 +82,7 @@ impl TemplateExpression {
                 format!("_ructe_out_.write_all({:?}.as_bytes())?;\n", text)
             }
             TemplateExpression::Expression { ref expr } => {
-                format!("{}.to_html(&mut _ructe_out_)?;\n", expr)
+                format!("{}.to_html(_ructe_out_)?;\n", expr)
             }
             TemplateExpression::ForLoop {
                 ref name,
@@ -126,7 +126,7 @@ impl TemplateExpression {
             ),
             TemplateExpression::CallTemplate { ref name, ref args } => {
                 format!(
-                    "{}(&mut _ructe_out_{})?;\n",
+                    "{}(_ructe_out_{})?;\n",
                     name,
                     args.iter().format_with("", |arg, f| f(&format_args!(
                         ", {}",
